# ShrtCde (ShortCode)
A small python library for lazy devs. This shortens the amount of code you have to write for your program with the help of functions.

## LICENSE
This project uses the Apache-2.0 license. For more info, check LICENSE.

## INSTALLATION
```
pip install ShrtCde
```
or
```
pip3 install ShrtCde
```

### LINKS
GitHub repo w/ examples: https://github.com/Uralstech/ShrtCde
GitHub Wiki: https://github.com/Uralstech/ShrtCde/wiki